@@ -2,5 +2,5 @@
 # SPDX - License - Identifier: MIT
 
 from showinfm.showinfm import (
-    show_in_file_manager, get_valid_file_manager, get_user_file_manager, get_stock_file_manager
+    show_in_file_manager, valid_file_manager, user_file_manager, stock_file_manager
 )
